@@ -1,6 +1,6 @@
 /**
  * 
- * $Id: LayoutT.h,v 1.3 2000/11/07 12:33:13 amai Exp $
+ * $Id: LayoutT.h,v 1.1 2004/08/28 19:23:25 dannybackx Exp $
  *
  * Copyright (C) 1998 Free Software Foundation, Inc.
  * Copyright (C) 1998-2000 LessTif Development Team
@@ -34,7 +34,7 @@
 extern "C" {
 #endif
 
-extern XrmQuark XmQTspecifyLayoutDirection;
+XMLIBEXPORT extern XrmQuark XmQTspecifyLayoutDirection;
 
 typedef XmDirection (*XmGetLayoutDirectionProc)(Widget);
 
