@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.2 2004/09/27 17:44:42 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.3 2004/10/27 19:05:19 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.2 2004/09/27 17:44:42 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/BulletinBoard.c,v 1.3 2004/10/27 19:05:19 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -460,41 +460,26 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     XmBulletinBoardWidget bb = (XmBulletinBoardWidget)new_w;
     XmBulletinBoardWidgetClass bbclass;
 
-    if (!BB_LabelFontList(bb))
-    {
-	BB_LabelFontList(bb) = _XmGetDefaultFontList(new_w, XmLABEL_FONTLIST);
-    }
-    else
-    {
-	XmFontList	o = BB_LabelFontList(new_w);
-	BB_LabelFontList(bb) = XmFontListCopy(BB_LabelFontList(new_w));
-	if (o)
-		XmFontListFree(o);
-    }
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "BB Initialize LabelFontList %p ButtonFontList %p\n",
+			    BB_LabelFontList(bb), BB_ButtonFontList(bb)));
 
-    if (!BB_ButtonFontList(bb))
-    {
-	BB_ButtonFontList(bb) = _XmGetDefaultFontList(new_w, XmBUTTON_FONTLIST);
-    }
-    else
-    {
-	XmFontList	o = BB_ButtonFontList(new_w);
-	BB_ButtonFontList(bb) = XmFontListCopy(BB_ButtonFontList(new_w));
-	if (o)
-		XmFontListFree(o);
-    }
+        if (!BB_LabelFontList(bb)) {
+		BB_LabelFontList(bb) = _XmGetDefaultFontList(new_w, XmLABEL_FONTLIST);
+        } else {
+		BB_LabelFontList(bb) = XmFontListCopy(BB_LabelFontList(new_w));
+	}
 
-    if (!BB_TextFontList(bb))
-    {
-	BB_TextFontList(bb) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
-    }
-    else
-    {
-	XmFontList	o = BB_TextFontList(new_w);
-	BB_TextFontList(bb) = XmFontListCopy(BB_TextFontList(new_w));
-	if (o)
-		XmFontListFree(o);
-    }
+	if (!BB_ButtonFontList(bb)) {
+		BB_ButtonFontList(bb) = _XmGetDefaultFontList(new_w, XmBUTTON_FONTLIST);
+	} else {
+		BB_ButtonFontList(bb) = XmFontListCopy(BB_ButtonFontList(new_w));
+	}
+
+	if (!BB_TextFontList(bb)) {
+		BB_TextFontList(bb) = _XmGetDefaultFontList(new_w, XmTEXT_FONTLIST);
+	} else {
+		BB_TextFontList(bb) = XmFontListCopy(BB_TextFontList(new_w));
+	}
 
     if (((XmBulletinBoardWidgetClass)XtClass(new_w))->bulletin_board_class.always_install_accelerators)
     {
