@@ -1,6 +1,6 @@
 /**
  *
- * $Id: DebugUtil.c,v 1.5 2004/09/27 15:32:25 dannybackx Exp $
+ * $Id: DebugUtil.c,v 1.6 2004/10/16 16:52:03 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright (C) 1995-2002 LessTif Development Team 
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DebugUtil.c,v 1.5 2004/09/27 15:32:25 dannybackx Exp $";
+static const char rcsid[] = "$Id: DebugUtil.c,v 1.6 2004/10/16 16:52:03 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -1509,7 +1509,6 @@ _LtDebugPrintString(const char *s)
 /* The following calls shouldn't depend on the complete debugging 
    subsystem, i.e. things like _LtDebugFile, etc. */
 
-#if XmVERSION > 1
 extern const char *
 _LtDebugComboBoxType2String(unsigned char type)
 {
@@ -1525,8 +1524,6 @@ _LtDebugComboBoxType2String(unsigned char type)
 	return("UNKNOWN");
     }
 }
-#endif
-
 
 extern const char *
 _LtDebugGeoAction2String(int action)
@@ -2398,6 +2395,22 @@ _LtDebugFocusDetail2String(int type)
 	}
 }
 
+extern const char *
+_LtDebugFrameChildType2String(int action)
+{
+	switch(action)
+	{
+	case XmFRAME_GENERIC_CHILD:
+		return("XmFRAME_GENERIC_CHILD");
+	case XmFRAME_WORKAREA_CHILD:
+		return("XmFRAME_WORKAREA_CHILD");
+	case XmFRAME_TITLE_CHILD:
+		return("XmFRAME_TITLE_CHILD");
+	default:
+		return("Unknown frame childtype");
+	}
+}
+
 extern void
 _LtDebugAction(const char *fn, Widget w, const String action,
 		const String *params, const Cardinal *num_params)
