@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.3 2004/09/23 20:59:34 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.7 2004/10/27 19:31:15 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.3 2004/09/23 20:59:34 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.7 2004/10/27 19:31:15 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -674,6 +674,10 @@ MLM: WHY TRAVERSAL?
 	    XtClass(new_w) == xmLabelWidgetClass
 	    ? XmLABEL_FONTLIST
 	    : XmBUTTON_FONTLIST);
+	if (Lab_Font(request)) {
+			XmFontListFree(Lab_Font(request));
+			Lab_Font(request) = NULL;
+	}
     }
     /* if the user specified one, COPY it */
     else
@@ -769,6 +773,7 @@ destroy(Widget w)
     _XmStringFree(Lab_AcceleratorText(w));
     _XmStringFree(Lab_Label(w));
     XmFontListFree(Lab_Font(w));
+    Lab_Font(w) = NULL;
 }
 
 
@@ -866,6 +871,7 @@ set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num
     if (Lab_Font(new_w) != Lab_Font(old))
     {
 	XmFontListFree(Lab_Font(old));
+	Lab_Font(old) = NULL;
 	if (Lab_Font(new_w) == (XmFontList)XmUNSPECIFIED ||
 	    Lab_Font(new_w) == NULL)
 	{
