@@ -1,9 +1,9 @@
 /**
  * 
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MenuShell.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MenuShell.c,v 1.5 2004/10/27 19:31:15 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MenuShell.c,v 1.1 2004/08/28 19:22:44 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/MenuShell.c,v 1.5 2004/10/27 19:31:15 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -234,47 +234,30 @@ initialize(Widget request, Widget new_w,
 
     if (MS_DefaultFontList(new_w) != NULL)
     {
-	MS_DefaultFontList(new_w) =
-	    XmFontListCopy(MS_DefaultFontList(new_w));
+	MS_DefaultFontList(new_w) = XmFontListCopy(MS_DefaultFontList(new_w));
     }
     else
     {
-	MS_DefaultFontList(new_w) = _XmGetDefaultFontList(new_w,
-							 XmBUTTON_FONTLIST);
+	MS_DefaultFontList(new_w) = _XmGetDefaultFontList(new_w, XmBUTTON_FONTLIST);
     }
     if (MS_ButtonFontList(new_w) == NULL)
     {
-	if (MS_DefaultFontList(new_w) != NULL)
-	{
-	    MS_ButtonFontList(new_w) =
-		XmFontListCopy(MS_DefaultFontList(new_w));
+	if (MS_DefaultFontList(new_w) != NULL) {
+	    MS_ButtonFontList(new_w) = XmFontListCopy(MS_DefaultFontList(new_w));
+	} else {
+	    MS_ButtonFontList(new_w) = _XmGetDefaultFontList(new_w, XmBUTTON_FONTLIST);
 	}
-	else
-	{
-	    MS_ButtonFontList(new_w) = _XmGetDefaultFontList(new_w,
-							     XmBUTTON_FONTLIST);
-	}
-    }
-    else
-    {
+    } else {
 	MS_ButtonFontList(new_w) = XmFontListCopy(MS_ButtonFontList(new_w));
     }
 
-    if (MS_LabelFontList(new_w) == NULL)
-    {
-	if (MS_DefaultFontList(new_w) != NULL)
-	{
-	    MS_LabelFontList(new_w) =
-		XmFontListCopy(MS_DefaultFontList(new_w));
+    if (MS_LabelFontList(new_w) == NULL) {
+	if (MS_DefaultFontList(new_w) != NULL) {
+	    MS_LabelFontList(new_w) = XmFontListCopy(MS_DefaultFontList(new_w));
+	} else {
+	    MS_LabelFontList(new_w) = _XmGetDefaultFontList(new_w, XmLABEL_FONTLIST);
 	}
-	else
-	{
-	    MS_LabelFontList(new_w) = _XmGetDefaultFontList(new_w,
-							    XmLABEL_FONTLIST);
-	}
-    }
-    else
-    {
+    } else {
 	MS_LabelFontList(new_w) = XmFontListCopy(MS_LabelFontList(new_w));
     }
 
@@ -753,6 +736,43 @@ MenuShellPopdownDone(Widget w, XEvent *event,
 		       "MenuShellPopdownDone - found RC %s, posted: %s\n",
 			XtName(rc), RC_PopupPosted(rc) ? XtName(RC_PopupPosted(rc)) : "NULL"));
 
+#if 1
+    /*
+     * Don't use an event that's within the multi click time.
+     * Hopefully this is an event which we can discard :-)
+     * If we get bug reports about things not disappearing when
+     * the user is fast, this is the reason.
+     * Danny 22/04/1998
+     *
+     * I also have a bad feeling about the test above. Is it meant to do
+     * what I changed it to below ?
+     */
+    /* Danny had this ifdef'd out, but it seems to be exactly what
+     * Motif does, so I put it back in.  In Motif, a quick click/release 
+     * causes the menu to "stick" open.
+     * 	-dwilliss 28-Sep-04
+     */
+    if (_XmMenuGetInPMMode(w) && event && event->type == ButtonRelease &&
+	event->xbutton.time <= state->RC_ButtonEventStatus.time
+				+ XtGetMultiClickTime(XtDisplay(w)))
+    {
+        if (RC_Type(rc) != XmMENU_OPTION)
+        {
+	   /* Not that this _shouldn't_ be done for option menus, but I'm
+	    * not sure if this is the correct way to do it for option menus,
+	    * so in that case, leave them alone for now
+	    *  -- dwilliss 28-Sep-04
+	    */
+	    _XmMenuFocus(rc, XmMENU_FOCUS_SAVE, CurrentTime);
+	    RCClass_MenuTraverse(rc, XmTRAVERSE_HOME);
+	    XAllowEvents(XtDisplay(rc), SyncPointer, event->xbutton.time);
+        }
+      DEBUGOUT(_LtDebug(__FILE__, w, "MenuShellPopdownDone(): exiting b/c user too fast\n"));
+	return;
+    }
+#endif
+
+
     _XmGetActiveTopLevelMenu(rc, &toplevelrc);
 
     if (!toplevelrc)
