@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/ResConvert.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/ResConvert.c,v 1.7 2004/11/28 10:32:27 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: ResConvert.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $";
+static const char rcsid[] = "$Id: ResConvert.c,v 1.7 2004/11/28 10:32:27 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -99,7 +99,6 @@ static void destroy_xm_string_table(XtAppContext app, XrmValue *to,
 				    Cardinal *num_args);
 static void get_unit_type(Widget w, Cardinal *size, XrmValue *val);
 
-#if XmVERSION > 1
 static Boolean _XmCvtStringToTabList(Display *display, XrmValue *args,
 		       Cardinal *num_args, XrmValue *from, XrmValue *to,
 		       XtPointer *converter_data);
@@ -117,7 +116,6 @@ static Boolean XmuCvtStringToXftColor(Display *dpy,
 static void XmuFreeXftColor(XtAppContext app, XrmValuePtr toVal, XtPointer closure,
                  XrmValuePtr args, Cardinal *num_args);
 #endif	/* USE_XFT */
-#endif /* XmVERSION > 1 */
 
 
 /*
@@ -389,19 +387,15 @@ static char *indicator_types[] =
 {
     "n_of_many",
     "one_of_many",
-#if XmVERSION > 1
     "one_of_many_round",
     "one_of_many_diamond"
-#endif
 };
 static unsigned char indicator_type_values[] =
 {
     XmN_OF_MANY,
     XmONE_OF_MANY,
-#if XmVERSION > 1
     XmONE_OF_MANY_ROUND,
     XmONE_OF_MANY_DIAMOND
-#endif
 };
 
 static char *resize_policies[] =
@@ -543,7 +537,6 @@ static XtConvertArgRec selfArgs[] = {
 		sizeof(Widget) }
 };
 
-#if XmVERSION > 1
 static char *toggle_mode[] =
 {
     "toggle_boolean",
@@ -558,6 +551,7 @@ static char *combobox_type[] =
    "drop_down_combo_box",
    "drop_down_list",
 };
+
 static unsigned char combobox_type_values[] =
 {
    XmCOMBO_BOX,
@@ -674,8 +668,6 @@ static char *path_mode_names[] =
 	"path_mode_full",
 	"path_mode_relative"
 };
-#endif /* XmVERSION > 1 */
-
 
 extern void
 XmRegisterConverters(void)
@@ -690,399 +682,352 @@ XmRegisterConverters(void)
 extern void
 _XmRegisterConverters(void)
 {
-    static Boolean first = True;
-    static XtConvertArgRec immediate_arg = {XtImmediate, 0, sizeof(XtPointer)};
-    static XtConvertArgRec horizontal_args[] = {
-	{
-	    XtWidgetBaseOffset,
-	    (XtPointer)XtOffset(Widget, core.screen),
-	    sizeof(Screen *)
-	},
-	{
-	    XtImmediate,
-	    (XtPointer)XmHORIZONTAL,
-	    sizeof(XtPointer)
-	},
-	{
-	    XtProcedureArg,
-	    (XtPointer)get_unit_type,
-	    0
-	}};
-    static XtConvertArgRec vertical_args[] = {
-	{
-	    XtWidgetBaseOffset,
-	    (XtPointer)XtOffset(Widget, core.screen),
-	    sizeof(Screen *)
-	},
-	{
-	    XtImmediate,
-	    (XtPointer)XmVERTICAL,
-	    sizeof(XtPointer)
-	},
-	{
-	    XtProcedureArg,
-	    (XtPointer)get_unit_type,
-	    0
-	}};
+	static Boolean first = True;
+	static XtConvertArgRec immediate_arg = {XtImmediate, 0, sizeof(XtPointer)};
+	static XtConvertArgRec horizontal_args[] = {
+		{ XtWidgetBaseOffset, (XtPointer)XtOffset(Widget, core.screen), sizeof(Screen *) },
+		{ XtImmediate, (XtPointer)XmHORIZONTAL, sizeof(XtPointer) },
+		{ XtProcedureArg, (XtPointer)get_unit_type, 0 }
+	};
+	static XtConvertArgRec vertical_args[] = {
+		{ XtWidgetBaseOffset, (XtPointer)XtOffset(Widget, core.screen), sizeof(Screen *) },
+		{ XtImmediate, (XtPointer)XmVERTICAL, sizeof(XtPointer) },
+		{ XtProcedureArg, (XtPointer)get_unit_type, 0 }
+	};
 
-    if (first)
-    {
-	first = False;
-    }
-    else
-    {
-	return;
-    }
+	if (first) {
+		first = False;
+	} else {
+		return;
+	}
 
-/* See comment at declaration at beginning of this file */
+	/* See comment at declaration at beginning of this file */
 #if XmVersion < 2001
-    xmUseVersion = XmVersion;
+	xmUseVersion = XmVersion;
 #endif
 
 #define REPTYPE_REGISTER(reptype,array) \
-    XmRepTypeRegister((reptype), \
-                     (array), \
-                     NULL, XtNumber((array)));
+	XmRepTypeRegister((reptype), \
+	(array), \
+	NULL, XtNumber((array)));
 #define REPTYPE_REGISTER_WITH_VALUES(reptype,array,values) \
-    XmRepTypeRegister((reptype), \
-                     (array), \
-                     (values), XtNumber((array)));
+	XmRepTypeRegister((reptype), \
+	(array), \
+	(values), XtNumber((array)));
 
-    REPTYPE_REGISTER(XmRMultiClick, multi_click);
-    REPTYPE_REGISTER(XmRPacking, packing_styles);
-    REPTYPE_REGISTER(XmRKeyboardFocusPolicy, focus_policies);
-    REPTYPE_REGISTER(XmRVerticalAlignment, vertical_alignments);
-    REPTYPE_REGISTER(XmRChildVerticalAlignment, child_vertical_alignments);
-    REPTYPE_REGISTER(XmRAlignment, horizontal_alignments);
-    REPTYPE_REGISTER(XmRChildHorizontalAlignment, horizontal_alignments);
-    REPTYPE_REGISTER(XmRArrowDirection, arrow_directions);
-    REPTYPE_REGISTER(XmRAttachment, attachments);
-    REPTYPE_REGISTER(XmRAudibleWarning, audible_warnings);
-    REPTYPE_REGISTER(XmRChildType, frame_child_types);
-    REPTYPE_REGISTER(XmRDeleteResponse, delete_responses);
-    REPTYPE_REGISTER(XmRNavigationType, navigation_types);
-    REPTYPE_REGISTER(XmRScrollBarPlacement, scrollbar_placement);
-    REPTYPE_REGISTER(XmRScrollingPolicy, scrolling_policy);
-    REPTYPE_REGISTER(XmRScrollBarDisplayPolicy, scrollbar_policy);
-    REPTYPE_REGISTER(XmREditMode, edit_mode);
-    REPTYPE_REGISTER(XmRDragInitiatorProtocolStyle, protocol_styles);
-    REPTYPE_REGISTER(XmRDragReceiverProtocolStyle, protocol_styles);
-    REPTYPE_REGISTER(XmRUnitType, unit_types);
-    REPTYPE_REGISTER(XmRDialogType, dialog_types);
-    REPTYPE_REGISTER(XmRSelectionType, selection_dialog_types);
-    REPTYPE_REGISTER(XmRDialogStyle, dialog_styles);
-    REPTYPE_REGISTER(XmRSeparatorType, separator_types);
-    REPTYPE_REGISTER(XmRResizePolicy, resize_policies);
-    REPTYPE_REGISTER(XmRIconAttachment, icon_attachments);
-    REPTYPE_REGISTER(XmRTransferStatus, transfer_statuses);
-    REPTYPE_REGISTER(XmRStringDirection, string_directions);
-    REPTYPE_REGISTER(XmRCommandWindowLocation, command_locations);
-    REPTYPE_REGISTER(XmRProcessingDirection, processing_directions);
-    REPTYPE_REGISTER(XmRUnpostBehavior, unpost_behaviours);
-    REPTYPE_REGISTER(XmRVisualPolicy, visual_policies);
-    REPTYPE_REGISTER(XmRChildPlacement, child_placements);
-    REPTYPE_REGISTER(XmRSelectionPolicy, selection_policies);
-    REPTYPE_REGISTER(XmRListSizePolicy, list_size_policies);
+	REPTYPE_REGISTER(XmRMultiClick, multi_click);
+	REPTYPE_REGISTER(XmRPacking, packing_styles);
+	REPTYPE_REGISTER(XmRKeyboardFocusPolicy, focus_policies);
+	REPTYPE_REGISTER(XmRVerticalAlignment, vertical_alignments);
+	REPTYPE_REGISTER(XmRChildVerticalAlignment, child_vertical_alignments);
+	REPTYPE_REGISTER(XmRAlignment, horizontal_alignments);
+	REPTYPE_REGISTER(XmRChildHorizontalAlignment, horizontal_alignments);
+	REPTYPE_REGISTER(XmRArrowDirection, arrow_directions);
+	REPTYPE_REGISTER(XmRAttachment, attachments);
+	REPTYPE_REGISTER(XmRAudibleWarning, audible_warnings);
+	REPTYPE_REGISTER(XmRChildType, frame_child_types);
+	REPTYPE_REGISTER(XmRDeleteResponse, delete_responses);
+	REPTYPE_REGISTER(XmRNavigationType, navigation_types);
+	REPTYPE_REGISTER(XmRScrollBarPlacement, scrollbar_placement);
+	REPTYPE_REGISTER(XmRScrollingPolicy, scrolling_policy);
+	REPTYPE_REGISTER(XmRScrollBarDisplayPolicy, scrollbar_policy);
+	REPTYPE_REGISTER(XmREditMode, edit_mode);
+	REPTYPE_REGISTER(XmRDragInitiatorProtocolStyle, protocol_styles);
+	REPTYPE_REGISTER(XmRDragReceiverProtocolStyle, protocol_styles);
+	REPTYPE_REGISTER(XmRUnitType, unit_types);
+	REPTYPE_REGISTER(XmRDialogType, dialog_types);
+	REPTYPE_REGISTER(XmRSelectionType, selection_dialog_types);
+	REPTYPE_REGISTER(XmRDialogStyle, dialog_styles);
+	REPTYPE_REGISTER(XmRSeparatorType, separator_types);
+	REPTYPE_REGISTER(XmRResizePolicy, resize_policies);
+	REPTYPE_REGISTER(XmRIconAttachment, icon_attachments);
+	REPTYPE_REGISTER(XmRTransferStatus, transfer_statuses);
+	REPTYPE_REGISTER(XmRStringDirection, string_directions);
+	REPTYPE_REGISTER(XmRCommandWindowLocation, command_locations);
+	REPTYPE_REGISTER(XmRProcessingDirection, processing_directions);
+	REPTYPE_REGISTER(XmRUnpostBehavior, unpost_behaviours);
+	REPTYPE_REGISTER(XmRVisualPolicy, visual_policies);
+	REPTYPE_REGISTER(XmRChildPlacement, child_placements);
+	REPTYPE_REGISTER(XmRSelectionPolicy, selection_policies);
+	REPTYPE_REGISTER(XmRListSizePolicy, list_size_policies);
 
-    REPTYPE_REGISTER_WITH_VALUES(XmRLabelType, label_types, label_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRShadowType, shadow_types,
-				 shadow_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRRowColumnType, row_column_types,
-				 row_column_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRExtensionType, extension_types,
-				 extension_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRFileTypeMask, file_types,
-				 file_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRDefaultButtonType, default_button_types,
-				 default_button_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmROrientation, orientations,
-				 orientation_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRIndicatorType, indicator_types,
-                                indicator_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRLabelType, label_types, label_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRShadowType, shadow_types, shadow_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRRowColumnType, row_column_types, row_column_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRExtensionType, extension_types, extension_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRFileTypeMask, file_types, file_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRDefaultButtonType, default_button_types,
+			default_button_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmROrientation, orientations, orientation_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRIndicatorType, indicator_types, indicator_type_values);
 
-#if XmVERSION > 1
-/* Motif 2.x */
-    REPTYPE_REGISTER(XmRToggleMode, toggle_mode);
-    REPTYPE_REGISTER_WITH_VALUES(XmRArrowLayout,
-                spb_arrow_layouts, spb_arrow_layout_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRSpinBoxChildType,
-                spb_child_types, spb_child_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRIndicatorOn,
-                indicator_on, indicator_on_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRNotebookChildType,
-                nb_child_types, nb_child_type_values);
-    REPTYPE_REGISTER_WITH_VALUES(XmRComboBoxType,
-                combobox_type, combobox_type_values);
+	/* Motif 2.x */
+	REPTYPE_REGISTER(XmRToggleMode, toggle_mode);
+	REPTYPE_REGISTER_WITH_VALUES(XmRArrowLayout, spb_arrow_layouts, spb_arrow_layout_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRSpinBoxChildType, spb_child_types, spb_child_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRIndicatorOn, indicator_on, indicator_on_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRNotebookChildType, nb_child_types, nb_child_type_values);
+	REPTYPE_REGISTER_WITH_VALUES(XmRComboBoxType, combobox_type, combobox_type_values);
 
-    REPTYPE_REGISTER(XmRFileFilterStyle, filter_styles);
-    REPTYPE_REGISTER(XmRPathMode, path_mode_names);
+	REPTYPE_REGISTER(XmRFileFilterStyle, filter_styles);
+	REPTYPE_REGISTER(XmRPathMode, path_mode_names);
 
-    XmRepTypeInstallTearOffModelConverter();
-#endif /* XmVERSION > 1 */
+	XmRepTypeInstallTearOffModelConverter();
 
 #undef REPTYPE_REGISTER
 #undef REPTYPE_REGISTER_WITH_VALUES
 
-    /* now we install the other toolkit converters */
+	/* now we install the other toolkit converters */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRXmString,	/* target type */
-		       _XmCvtStringToXmString,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheAll,	/* caching instructions */
-		       NULL);	/* destructor function */
-#if 1
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRXmString,	/* target type */
+		_XmCvtStringToXmString,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheAll,	/* caching instructions */
+		NULL);	/* destructor function */
 	/* Don't cache */
 	XtSetTypeConverter(XtRString,		/* source type */
 		XmRFontList,			/* target type */
 		_XmCvtStringToXmFontList,	/* converter routine */
 		NULL,				/* args for converter routine */
 		0,				/* number of args to converter routine */
-		XtCacheNone,			/* caching instructions */
-		destroy_font_list);				/* destructor function */
-#else
-    XtSetTypeConverter(XtRString,		/* source type */
-		XmRFontList,			/* target type */
-		_XmCvtStringToXmFontList,	/* converter routine */
-		NULL,				/* args for converter routine */
-		0,				/* number of args to converter routine */
-		XtCacheByDisplay,	/* caching instructions */
-		destroy_font_list);	/* destructor function */
-#endif
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRHorizontalDimension,	/* target type */
-		       _XmCvtStringToResIndDimension,	/* converter routine */
-		       horizontal_args,	/* args for converter routine */
-		       XtNumber(horizontal_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+		XtCacheByDisplay,		/* caching instructions */
+		destroy_font_list);		/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRHorizontalDimension,	/* target type */
+		_XmCvtStringToResIndDimension,	/* converter routine */
+		horizontal_args,	/* args for converter routine */
+		XtNumber(horizontal_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRShellHorizDim,	/* target type */
-		       _XmCvtStringToResIndDimension,	/* converter routine */
-		       horizontal_args,	/* args for converter routine */
-		       XtNumber(horizontal_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRShellHorizDim,	/* target type */
+		_XmCvtStringToResIndDimension,	/* converter routine */
+		horizontal_args,	/* args for converter routine */
+		XtNumber(horizontal_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRHorizontalInt,	/* target type */
-		       _XmCvtStringToResIndInt,	/* converter routine */
-		       horizontal_args,	/* args for converter routine */
-		       XtNumber(horizontal_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRHorizontalInt,	/* target type */
+		_XmCvtStringToResIndInt,	/* converter routine */
+		horizontal_args,	/* args for converter routine */
+		XtNumber(horizontal_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRHorizontalPosition,	/* target type */
-		       _XmCvtStringToResIndPosition, /* converter routine */
-		       horizontal_args,	/* args for converter routine */
-		       XtNumber(horizontal_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRHorizontalPosition,	/* target type */
+		_XmCvtStringToResIndPosition, /* converter routine */
+		horizontal_args,	/* args for converter routine */
+		XtNumber(horizontal_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRShellHorizPos,	/* target type */
-		       _XmCvtStringToResIndPosition, /* converter routine */
-		       horizontal_args,	/* args for converter routine */
-		       XtNumber(horizontal_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRShellHorizPos,	/* target type */
+		_XmCvtStringToResIndPosition, /* converter routine */
+		horizontal_args,	/* args for converter routine */
+		XtNumber(horizontal_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRShellVertPos,	/* target type */
-		       _XmCvtStringToResIndPosition,	/* converter routine */
-		       vertical_args,	/* args for converter routine */
-		       XtNumber(vertical_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRShellVertPos,	/* target type */
+		_XmCvtStringToResIndPosition,	/* converter routine */
+		vertical_args,	/* args for converter routine */
+		XtNumber(vertical_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRVerticalPosition,	/* target type */
-		       _XmCvtStringToResIndPosition,	/* converter routine */
-		       vertical_args,	/* args for converter routine */
-		       XtNumber(vertical_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRVerticalPosition,	/* target type */
+		_XmCvtStringToResIndPosition,	/* converter routine */
+		vertical_args,	/* args for converter routine */
+		XtNumber(vertical_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRShellVertDim,		/* target type */
-		       _XmCvtStringToResIndDimension,		/* converter routine */
-		       vertical_args,	/* args for converter routine */
-		       XtNumber(vertical_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRShellVertDim,		/* target type */
+		_XmCvtStringToResIndDimension,		/* converter routine */
+		vertical_args,	/* args for converter routine */
+		XtNumber(vertical_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRVerticalDimension,	/* target type */
-		       _XmCvtStringToResIndDimension,		/* converter routine */
-		       vertical_args,	/* args for converter routine */
-		       XtNumber(vertical_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRVerticalDimension,	/* target type */
+		_XmCvtStringToResIndDimension,		/* converter routine */
+		vertical_args,	/* args for converter routine */
+		XtNumber(vertical_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRVerticalInt,	/* target type */
-		       _XmCvtStringToResIndInt,	/* converter routine */
-		       vertical_args,	/* args for converter routine */
-		       XtNumber(vertical_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRVerticalInt,	/* target type */
+		_XmCvtStringToResIndInt,	/* converter routine */
+		vertical_args,	/* args for converter routine */
+		XtNumber(vertical_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRKeySym,	/* target type */
-		       _XmCvtStringToKeySym,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheAll,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRKeySym,	/* target type */
+		_XmCvtStringToKeySym,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheAll,	/* caching instructions */
+		NULL);	/* destructor function */
 
 #if 0
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRNavigation,	/* target type */
-		       _XmCvtStringToXmNavigation,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRNavigation,	/* target type */
+		_XmCvtStringToXmNavigation,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 #endif
 
-    immediate_arg.address_id = (XtPointer)ST_ATOM_LIST;
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRAtomList,	/* target type */
-		       _XmCvtStringToSomeTable,	/* converter routine */
-		       &immediate_arg,	/* args for converter routine */
-		       1,	/* number of args to converter routine */
-		       XtCacheNone | XtCacheRefCount,	/* caching instructions */
-		       destroy_table);	/* destructor function */
+	immediate_arg.address_id = (XtPointer)ST_ATOM_LIST;
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRAtomList,	/* target type */
+		_XmCvtStringToSomeTable,	/* converter routine */
+		&immediate_arg,	/* args for converter routine */
+		1,	/* number of args to converter routine */
+		XtCacheNone | XtCacheRefCount,	/* caching instructions */
+		destroy_table);	/* destructor function */
 
-    immediate_arg.address_id = (XtPointer)ST_BUTTON_TYPE;
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRButtonType,	/* target type */
-		       _XmCvtStringToSomeTable,	/* converter routine */
-		       &immediate_arg,	/* args for converter routine */
-		       1,	/* number of args to converter routine */
-		       XtCacheNone | XtCacheRefCount,	/* caching instructions */
-		       destroy_table);	/* destructor function */
+	immediate_arg.address_id = (XtPointer)ST_BUTTON_TYPE;
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRButtonType,	/* target type */
+		_XmCvtStringToSomeTable,	/* converter routine */
+		&immediate_arg,	/* args for converter routine */
+		1,	/* number of args to converter routine */
+		XtCacheNone | XtCacheRefCount,	/* caching instructions */
+		destroy_table);	/* destructor function */
 
-    immediate_arg.address_id = (XtPointer)ST_STRING_TABLE;
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRCharSetTable,	/* target type */
-		       _XmCvtStringToSomeTable,	/* converter routine */
-		       &immediate_arg,	/* args for converter routine */
-		       1,	/* number of args to converter routine */
-		       XtCacheNone | XtCacheRefCount,	/* caching instructions */
-		       destroy_string_table);	/* destructor function */
+	immediate_arg.address_id = (XtPointer)ST_STRING_TABLE;
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRCharSetTable,	/* target type */
+		_XmCvtStringToSomeTable,	/* converter routine */
+		&immediate_arg,	/* args for converter routine */
+		1,	/* number of args to converter routine */
+		XtCacheNone | XtCacheRefCount,	/* caching instructions */
+		destroy_string_table);	/* destructor function */
 
-    immediate_arg.address_id = (XtPointer)ST_KEY_SYM_TABLE;
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRKeySymTable,	/* target type */
-		       _XmCvtStringToSomeTable,	/* converter routine */
-		       &immediate_arg,	/* args for converter routine */
-		       1,	/* number of args to converter routine */
-		       XtCacheNone | XtCacheRefCount,	/* caching instructions */
-		       destroy_table);	/* destructor function */
+	immediate_arg.address_id = (XtPointer)ST_KEY_SYM_TABLE;
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRKeySymTable,	/* target type */
+		_XmCvtStringToSomeTable,	/* converter routine */
+		&immediate_arg,	/* args for converter routine */
+		1,	/* number of args to converter routine */
+		XtCacheNone | XtCacheRefCount,	/* caching instructions */
+		destroy_table);	/* destructor function */
 
-    immediate_arg.address_id = (XtPointer)ST_STRING_TABLE;
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRStringTable,	/* target type */
-		       _XmCvtStringToSomeTable,	/* converter routine */
-		       &immediate_arg,	/* args for converter routine */
-		       1,	/* number of args to converter routine */
-		       XtCacheNone | XtCacheRefCount,	/* caching instructions */
-		       destroy_string_table);	/* destructor function */
+	immediate_arg.address_id = (XtPointer)ST_STRING_TABLE;
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRStringTable,	/* target type */
+		_XmCvtStringToSomeTable,	/* converter routine */
+		&immediate_arg,	/* args for converter routine */
+		1,	/* number of args to converter routine */
+		XtCacheNone | XtCacheRefCount,	/* caching instructions */
+		destroy_string_table);	/* destructor function */
 
-    immediate_arg.address_id = (XtPointer)ST_XM_STRING_TABLE;
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRXmStringTable,	/* target type */
-		       _XmCvtStringToSomeTable,	/* converter routine */
-		       &immediate_arg,	/* args for converter routine */
-		       1,	/* number of args to converter routine */
-		       XtCacheNone | XtCacheRefCount,	/* caching instructions */
-		       destroy_xm_string_table);	/* destructor function */
+	immediate_arg.address_id = (XtPointer)ST_XM_STRING_TABLE;
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRXmStringTable,	/* target type */
+		_XmCvtStringToSomeTable,	/* converter routine */
+		&immediate_arg,	/* args for converter routine */
+		1,	/* number of args to converter routine */
+		XtCacheNone | XtCacheRefCount,	/* caching instructions */
+		destroy_xm_string_table);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRWidget,	/* target type */
-		       _XmCvtStringToWidget,	/* converter routine */
-		       parentArgs,	/* args for converter routine */
-		       XtNumber(parentArgs),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRWidget,	/* target type */
+		_XmCvtStringToWidget,	/* converter routine */
+		parentArgs,	/* args for converter routine */
+		XtNumber(parentArgs),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRWindow,	/* target type */
-		       _XmCvtStringToWindow,	/* converter routine */
-		       parentArgs,	/* args for converter routine */
-		       XtNumber(parentArgs),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRWindow,	/* target type */
+		_XmCvtStringToWindow,	/* converter routine */
+		parentArgs,	/* args for converter routine */
+		XtNumber(parentArgs),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRCardinal,	/* target type */
-		       _XmCvtStringToCardinal,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRCardinal,	/* target type */
+		_XmCvtStringToCardinal,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRBooleanDimension,	/* target type */
-		       _XmCvtStringToBooleanDimension,	/* converter routine */
-		       horizontal_args,	/* args for converter routine */
-		       XtNumber(horizontal_args),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRBooleanDimension,	/* target type */
+		_XmCvtStringToBooleanDimension,	/* converter routine */
+		horizontal_args,	/* args for converter routine */
+		XtNumber(horizontal_args),	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRChar,	/* target type */
-		       _XmCvtStringToChar,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRChar,	/* target type */
+		_XmCvtStringToChar,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRTextPosition,	/* target type */
-		       _XmCvtStringToTextPosition,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRTextPosition,	/* target type */
+		_XmCvtStringToTextPosition,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRTopItemPosition,	/* target type */
-		       _XmCvtStringToTopItemPosition,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
-#if XmVERSION > 1
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRTabList,	/* target type */
-		       _XmCvtStringToTabList,	/* converter routine */
-		       NULL,	/* args for converter routine */
-		       0,	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRTopItemPosition,	/* target type */
+		_XmCvtStringToTopItemPosition,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
+	XtSetTypeConverter(XtRString,	/* source type */
+		XmRTabList,	/* target type */
+		_XmCvtStringToTabList,	/* converter routine */
+		NULL,	/* args for converter routine */
+		0,	/* number of args to converter routine */
+		XtCacheNone,	/* caching instructions */
+		NULL);	/* destructor function */
 
-    XtSetTypeConverter(XtRString,	/* source type */
-		       XmRRenderTable,	/* target type */
-		       _XmCvtStringToRenderTable,	/* converter routine */
-		       selfArgs,	/* args for converter routine */
-		       XtNumber(selfArgs),	/* number of args to converter routine */
-		       XtCacheNone,	/* caching instructions */
-		       _XmCvtRenderTableFree);	/* destructor function */
+	XtSetTypeConverter(XtRString,			/* source type */
+		XmRRenderTable,			/* target type */
+		_XmCvtStringToRenderTable,	/* converter routine */
+		selfArgs,			/* args for converter routine */
+		XtNumber(selfArgs),		/* number of args to converter routine */
+		XtCacheByDisplay | XtCacheRefCount,	/* caching instructions */
+		_XmCvtRenderTableFree);		/* destructor function */
 #if	USE_XFT
-    XtSetTypeConverter (XtRString, XtRXftColor,
-			XmuCvtStringToXftColor,
-			xftColorConvertArgs, XtNumber(xftColorConvertArgs),
-			XtCacheByDisplay, XmuFreeXftColor);
+	XtSetTypeConverter(XtRString,
+		XtRXftColor,
+		XmuCvtStringToXftColor,
+		xftColorConvertArgs,
+		XtNumber(xftColorConvertArgs),
+		XtCacheByDisplay,
+		XmuFreeXftColor);
 #endif	/* USE_XFT */
-#endif	/* XmVERSION > 1 */
 
 #ifdef NONSTANDARD_CONVERTERS
-    _XmRegisterNSEConverters();
+	_XmRegisterNSEConverters();
 #endif
 }
 
@@ -1093,28 +1038,23 @@ _XmRegisterConverters(void)
 void
 _XmError(Widget w, const char *fmt, ...)
 {
-    va_list arg_list;
-    char buf[1024];
-    int charsleft=sizeof(buf);
+	va_list arg_list;
+	char buf[1024];
+	int charsleft=sizeof(buf);
 
-    va_start(arg_list, fmt);
+	va_start(arg_list, fmt);
 #ifdef HAVE_VSNPRINTF
-    charsleft -= vsnprintf(buf, sizeof(buf),
-                           fmt, arg_list);
+	charsleft -= vsnprintf(buf, sizeof(buf), fmt, arg_list);
 #else
-    charsleft -= vsprintf(buf,
-                          fmt, arg_list);
-    /* one might add a catch here ... */
+	charsleft -= vsprintf(buf, fmt, arg_list);
+	/* one might add a catch here ... */
 #endif
-    va_end(arg_list);
-    if (w)
-    {
-	XtAppError(XtWidgetToApplicationContext(w), buf);
-    }
-    else
-    {
-	XtError(buf);
-    }
+	va_end(arg_list);
+	if (w) {
+		XtAppError(XtWidgetToApplicationContext(w), buf);
+	} else {
+		XtError(buf);
+	}
 }
 
 
@@ -1214,14 +1154,9 @@ _LtWarning(Widget w, const char *fmt, va_list arg_list)
  * bugs of course :-(
  */
 
-/* unshadow for the Motif 2.x build and give prototype */
-#if XmVERSION >= 2
 #ifdef _XmWarning
 #undef _XmWarning
 #endif
-extern void
-_XmWarning(Widget w, const char *fmt, ...);
-#endif
 
 extern void
 _XmWarning(Widget w, const char *fmt, ...)
@@ -1234,7 +1169,6 @@ _XmWarning(Widget w, const char *fmt, ...)
 }
 
 
-#if XmVERSION >= 2
 extern void
 XmeWarning(Widget w, const char *fmt, ...)
 {
@@ -1244,7 +1178,6 @@ XmeWarning(Widget w, const char *fmt, ...)
     _LtWarning(w, fmt, arg_list);
     va_end(arg_list);
 }
-#endif
 
 
 extern char *
@@ -2685,6 +2618,7 @@ destroy_font_list(XtAppContext app, XrmValue *to,
 		  XtPointer converer_data, XrmValue *args,
 		  Cardinal *num_args)
 {
+	fprintf(stderr, "_XmCvtStringToXmFontList()\n");
     XmFontListFree(*(XmFontList *)to->addr);
 }
 
@@ -2736,7 +2670,6 @@ get_unit_type(Widget w, Cardinal *size, XrmValue *val)
     ut = _XmGetUnitType(w);
 }
 
-#if (XmVERSION > 1)
 /*
  * XmConvertStringToUnits converts a string specification value and returns
  * the converted value as the return value from the function. This function
@@ -2773,9 +2706,7 @@ XmConvertStringToUnits(Screen *screen, String spec, int orientation,
 	}
     return 0;
 }
-#endif
 
-#if (XmVERSION > 1)
 static Boolean
 _XmCvtStringToTabList(Display *display,
 		       XrmValue *args,
@@ -3034,7 +2965,7 @@ _XmRenditionFromResources(Display *dpy,
 	}
 #endif
 	if (searchlist)
-		XtFree(searchlist);
+		XtFree((char *)searchlist);
 	if (found && rp) {
 		*rp = r;
 		return True;
@@ -3251,6 +3182,17 @@ _XmCvtRenderTableFree(XtAppContext app, XrmValue *to,
 	int		i;
 	XmRenderTable	table = *(XmRenderTable *)to->addr;
 
+	for (i=0; i<table->count; i++) {
+		if (table->renditions[i]->type == XmFONT_IS_FONT) {
+			XFreeFont(table->dpy, (XFontStruct *)table->renditions[i]->font);
+		} else {
+			/* FIX ME */
+		}
+	}
+
+#if 0
+	fprintf(stderr, "_XmCvtRenderTableFree(%p)\n", table);
+#endif
 	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmCvtRenderTableFree(%p)\n", table));
 	XmRenderTableFree(table);
 }
@@ -3436,4 +3378,3 @@ XmCvtXmStringTableToTextProperty (Display *display,
         _XmWarning(NULL, "XmCvtXmStringTableToTextProperty() is not implemented yet!\n");
 	return 0;
 }				      
-#endif /* XmVERSION > 1 */
