@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Text.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Text.c,v 1.2 2004/10/21 18:54:00 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright  1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Text.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Text.c,v 1.2 2004/10/21 18:54:00 dannybackx Exp $";
 
 #define VERBOSE
 
@@ -46,11 +46,9 @@ static const char rcsid[] = "$Id: Text.c,v 1.1 2004/08/28 19:22:45 dannybackx Ex
 #include <Xm/CutPaste.h>
 #include <Xm/TransltnsP.h>
 #include <Xm/ScrolledW.h>
-#if XmVERSION > 1
 #include <Xm/XmIm.h>
 #include <Xm/TraitP.h>
 #include <Xm/AccTextT.h>
-#endif
 
 #include <XmI/XmI.h>
 
@@ -94,7 +92,6 @@ void _XmTextExportValue(Widget w, int offset, XtArgVal *value);
 static void TextGetValues(Widget w, ArgList args, Cardinal *num_args);
 
 
-#if XmVERSION > 1
 static XtPointer _XmText_TraitGetValue(Widget w, int format);
 static void _XmText_TraitSetValue(Widget w, XtPointer value, int format);
 static int _XmText_TraitPreferredFormat(Widget w);
@@ -106,7 +103,6 @@ XmAccessTextualTraitRec _XmTextTraitRec =
 		/* setValue */		_XmText_TraitSetValue,
 		/* preferredFormat */	_XmText_TraitPreferredFormat,
 	};
-#endif
 
 #define Offset(_name) XtOffsetOf(XmTextRec, text._name)
 
@@ -472,13 +468,11 @@ ClassInitialize(void)
 
     xmTextClassRec.core_class.num_actions = _XmdefaultTextActionsTableSize;
 
-#if XmVERSION > 1
     if (!XmeTraitSet((XtPointer)xmTextWidgetClass, XmQTaccessTextual,
                      (XtPointer) &_XmTextTraitRec)) {
 	DEBUGOUT(_LtDebug(__FILE__, NULL,
 		"ClassInitialize: XmeTraitSet failed\n"));
     }
-#endif
 }
 
 
@@ -659,9 +653,7 @@ Destroy(Widget w)
 {
     DEBUGOUT(_LtDebug(__FILE__, w, "Destroy\n"));
 
-#if XmVERSION > 1
     XmImCloseXIM(w);
-#endif
 
     /* rws 2 Oct 1998
      * This is odd, I thought Xt should be taking care of this
@@ -673,11 +665,9 @@ Destroy(Widget w)
     (*Text_Output(w)->destroy) (w);
     XtDestroyWidget(((XmTextWidget)w)->text.inner_widget);
 
-#if 1
     /* rws 1 Apr 1999
      */
     XtFree((char *)Text_LineTable(w));
-#endif
     if(Text_Line(w)) XtFree((char *)Text_Line(w));
     XtFree((char *)Text_Highlight(w).list);
     XtFree((char *)Text_OldHighlight(w).list);
@@ -3190,8 +3180,6 @@ _XmTextNumLines(XmTextWidget widget)
 	return Text_LineCount(widget);
 }
 
-
-#if XmVERSION > 1
 /*
  * Not sure whether I need to do all this copying.
  * FIX ME
@@ -3216,7 +3204,6 @@ _XmText_TraitGetValue(Widget w, int format)
 	}  
 }
 
-
 static void
 _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 {
@@ -3246,7 +3233,6 @@ _XmText_TraitSetValue(Widget w, XtPointer value, int format)
 	}
 }
 
-
 static int
 _XmText_TraitPreferredFormat(Widget w)
 {
@@ -3255,7 +3241,6 @@ _XmText_TraitPreferredFormat(Widget w)
 	return XmFORMAT_WCS;
 }
 
-
 extern Boolean
 XmTextCopyLink(Widget widget,
                Time time)
@@ -3263,5 +3248,3 @@ XmTextCopyLink(Widget widget,
    _XmWarning(NULL, "XmTextCopyLink(): not yet implemented!");
    return False;
 }
-
-#endif /* XmVERSION > 1 */
