@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/TextOut.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/TextOut.c,v 1.2 2004/10/21 18:54:00 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/TextOut.c,v 1.1 2004/08/28 19:22:45 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/TextOut.c,v 1.2 2004/10/21 18:54:00 dannybackx Exp $";
 
 /* Do NOT use this (USE_XT_GC) :
  * it requires setting all the dynamic GC fields before every use of
@@ -66,12 +66,7 @@ static void Draw(XmTextWidget w, LineNum num, XmTextPosition start, XmTextPositi
 #define Offset(field) XtOffsetOf(XmTextInnerRec, inner.out.field)
 
 
-#if XmVERSION > 1
 #define	USE_AVERAGE_WIDTH 1
-#else
-/* same behavior as XmTextField.*/
-#undef	USE_AVERAGE_WIDTH
-#endif
 
 #undef	Out_FontTextWidth
 #define	Out_FontTextWidth(o,s,l)	(int)_XmOut_FontTextWidth(o, s, l)
@@ -97,7 +92,7 @@ static XtResource output_resources[] =
 	sizeof(Boolean), Offset(cursor_position_visible),
 	XmRImmediate, (XtPointer)True
     },
-#if (XmVERSION > 1) && defined(USE_XFT)
+#ifdef USE_XFT
     /* Note that the right order is important here ! */
     {
 	"keep.off", "Keep.off", XmRBoolean,
