@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Vendor.c,v 1.2 2004/09/27 17:44:43 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Vendor.c,v 1.4 2004/10/27 19:31:15 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
+ * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Vendor.c,v 1.2 2004/09/27 17:44:43 dannybackx Exp $";
+static const char rcsid[] = "$Id: Vendor.c,v 1.4 2004/10/27 19:31:15 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -66,9 +66,7 @@ static const char rcsid[] = "$Id: Vendor.c,v 1.2 2004/09/27 17:44:43 dannybackx
 #include <Xm/ExtObjectP.h>
 #include <Xm/VendorS.h>
 
-#if XmVERSION > 1
 #include <Xm/TraitP.h>
-#endif
 
 #include <XmI/DebugUtil.h>
 
@@ -276,7 +274,6 @@ static XtResource ext_resources[] =
 	sizeof(int), Offset(foreground_threshold),
 	XtRImmediate, (XtPointer)0
     },
-#if XmVERSION > 1
     /* FIX ME which version does this originate at ? */
     {
 	XmNlayoutDirection, XmCLayoutDirection, XmRDirection,
@@ -288,7 +285,6 @@ static XtResource ext_resources[] =
 	sizeof(XmInputPolicy), Offset(input_policy),
 	XtRImmediate, (XtPointer)XmPER_SHELL
     },
-#endif
 };
 
 
@@ -708,10 +704,8 @@ class_initialize(void)
 	    ((XmShellExtObjectClass)xmShellExtClass)->
 		    shell_class.structureNotifyHandler;
     }
-#if XmVERSION > 1
     /* Initialize traits */
     _XmInitTraits();
-#endif
 }
 
 static void
@@ -1127,38 +1121,33 @@ _XmVendorExtDestroy(Widget w)
 	Atom wm_delete_window;
 	Widget shell = ExtObj_LogicalParent(w);
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "VendorShellExt Destroy()\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "VendorShellExt Destroy()\n"));
 
-	if (VSEP_DefaultFontList(ve))
-	{
-	XmFontListFree(VSEP_DefaultFontList(ve));
+	if (VSEP_DefaultFontList(ve)) {
+		XmFontListFree(VSEP_DefaultFontList(ve));
 	}
-	if (VSEP_ButtonFontList(ve))
-	{
-	XmFontListFree(VSEP_ButtonFontList(ve));
+	if (VSEP_ButtonFontList(ve)) {
+		XmFontListFree(VSEP_ButtonFontList(ve));
 	}
-	if (VSEP_TextFontList(ve))
-	{
-	XmFontListFree(VSEP_TextFontList(ve));
+	if (VSEP_TextFontList(ve)) {
+		XmFontListFree(VSEP_TextFontList(ve));
 	}
-	if (VSEP_LabelFontList(ve))
-	{
-	XmFontListFree(VSEP_LabelFontList(ve));
+	if (VSEP_LabelFontList(ve)) {
+		XmFontListFree(VSEP_LabelFontList(ve));
 	}
 
-    if (VSEP_MwmMenu(ve) != NULL)
-    {
-	  XtFree((char*)VSEP_MwmMenu(ve));
-    }
+	if (VSEP_MwmMenu(ve) != NULL) {
+		XtFree((char*)VSEP_MwmMenu(ve));
+	}
 
-    _XmDestroyFocusData(VSEP_FocusData(ve));
+	_XmDestroyFocusData(VSEP_FocusData(ve));
 
-    wm_delete_window = XmInternAtom(XtDisplay(shell), _XA_WM_DELETE_WINDOW, False);
+	wm_delete_window = XmInternAtom(XtDisplay(shell), _XA_WM_DELETE_WINDOW, False);
 
-    /* This removes all protocols and destroys the associated extension object */
-    _XmDestroyProtocols(shell);
-    _XtRemoveCallback(&VSEP_RealizeCallback(w), _XmVendorExtRealize, NULL);
-    XtFree((char *)w);
+	/* This removes all protocols and destroys the associated extension object */
+	_XmDestroyProtocols(shell);
+	_XtRemoveCallback(&VSEP_RealizeCallback(w), _XmVendorExtRealize, NULL);
+	XtFree((char *)w);
 }
 
 
@@ -3137,10 +3126,7 @@ _XmVendorExtInitialize(Widget req,
 
     if (VSEP_DefaultFontList(ve) != NULL)
     {
-	XmFontList	o = VSEP_DefaultFontList(ve);
 	VSEP_DefaultFontList(ve) = XmFontListCopy(VSEP_DefaultFontList(ve));
-	if (o)
-		XmFontListFree(o);
     }
 
     /* initialize the button font list */
@@ -3153,10 +3139,7 @@ _XmVendorExtInitialize(Widget req,
 		_XmGetDefaultFontList(ExtObj_LogicalParent(new_w), XmBUTTON_FONTLIST);
 	}
     } else {
-	XmFontList	o = VSEP_ButtonFontList(ve);
 	VSEP_ButtonFontList(ve) = XmFontListCopy(VSEP_ButtonFontList(ve));
-	if (o)
-		XmFontListFree(o);
     }
 
     /* initialize the label font list */
@@ -3168,10 +3151,7 @@ _XmVendorExtInitialize(Widget req,
 		_XmGetDefaultFontList(ExtObj_LogicalParent(new_w), XmLABEL_FONTLIST);
 	}
     } else {
-	XmFontList	o = VSEP_LabelFontList(ve);
 	VSEP_LabelFontList(ve) = XmFontListCopy(VSEP_LabelFontList(ve));
-	if (o)
-		XmFontListFree(o);
     }
 
     /* initialize the text font list */
@@ -3183,10 +3163,7 @@ _XmVendorExtInitialize(Widget req,
 		_XmGetDefaultFontList(ExtObj_LogicalParent(new_w), XmTEXT_FONTLIST);
 	}
     } else {
-	XmFontList	o = VSEP_TextFontList(ve);
 	VSEP_TextFontList(ve) = XmFontListCopy(VSEP_TextFontList(ve));
-	if (o)
-		XmFontListFree(o);
     }
 
     VSEP_MwmHints(ve).flags = 0;
